YustTextField class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- YustTextField
Constructors
-
YustTextField({Key? key, String? label, IconData? labelIcon, String? value, String? helperText, String? placeholder, TextStyle? placeholderTextStyle, TextStyle? textStyle, StringCallback? onChanged, StringCallback? onEditingComplete, StringCallback? onFieldSubmitted, TextEditingController? controller, FormFieldValidator<
String> ? validator, TapCallback? onTap, DeleteCallback? onDelete, int? maxLength, int? maxLines, TextStyle? labelStyle, int? minLines, bool expands = false, bool enabled = true, bool autocorrect = true, bool readOnly = false, bool slimDesign = false, bool obscureText = false, bool autofocus = false, bool notTrim = false, bool hideKeyboardOnAutofocus = false, FocusNode? focusNode, YustInputStyle? style = YustInputStyle.normal, bool divider = true, Widget? prefixIcon, Widget? suffixIcon, TextStyle? suffixStyle, TextCapitalization textCapitalization = TextCapitalization.sentences, AutovalidateMode? autovalidateMode, List<TextInputFormatter> inputFormatters = const [], SmartQuotesType? smartQuotesType, TextInputType? keyboardType, TextInputAction? textInputAction, EdgeInsets contentPadding = const EdgeInsets.fromLTRB(16.0, 20.0, 20.0, 20.0), bool shouldCompleteNotValidInput = false, bool completeOnUnfocus = true, Iterable<String> ? autofillHints, bool reserveDefaultTextEditingShortcuts = true, String? forceErrorText, IconData? prefixLabelIcon, Color? prefixLabelIconColor}) -
const
-
YustTextField.filled({Key? key, String? label, IconData? labelIcon, String? value, String? helperText, String? placeholder, TextStyle? placeholderTextStyle, TextStyle? textStyle, StringCallback? onChanged, StringCallback? onEditingComplete, StringCallback? onFieldSubmitted, TextEditingController? controller, FormFieldValidator<
String> ? validator, TapCallback? onTap, DeleteCallback? onDelete, int? maxLength, int? maxLines, TextStyle? labelStyle, int? minLines, bool expands = false, bool enabled = true, bool autocorrect = true, bool readOnly = false, bool slimDesign = false, bool obscureText = false, bool autofocus = false, bool notTrim = false, bool hideKeyboardOnAutofocus = false, FocusNode? focusNode, YustInputStyle? style = YustInputStyle.normal, bool divider = true, Widget? prefixIcon, Widget? suffixIcon, TextStyle? suffixStyle, TextCapitalization textCapitalization = TextCapitalization.sentences, AutovalidateMode? autovalidateMode, List<TextInputFormatter> inputFormatters = const [], SmartQuotesType? smartQuotesType, TextInputType? keyboardType, TextInputAction? textInputAction, EdgeInsets contentPadding = const EdgeInsets.fromLTRB(12, 8, 12, 8), bool shouldCompleteNotValidInput = false, bool completeOnUnfocus = true, Iterable<String> ? autofillHints, bool reserveDefaultTextEditingShortcuts = true, String? forceErrorText, IconData? prefixLabelIcon, Color? prefixLabelIconColor, Color? filledInputDecorationColor}) -
const
Properties
- autocorrect → bool
-
final
-
autofillHints
→ Iterable<
String> ? -
final
- autofocus → bool
-
final
- autovalidateMode → AutovalidateMode?
-
final
- completeOnUnfocus → bool
-
if false, onEditingComplete gets triggered only on
enter or submit but not on unfocus
final
- contentPadding → EdgeInsets
-
final
- controller → TextEditingController?
-
final
- divider → bool
-
final
- enabled → bool
-
final
- expands → bool
-
final
- filledInputDecorationColor → Color?
-
The color to be used for InputDecoration.fillColor if useFilledInputDecoration is true
If null, the default color from the current Theme will be used
final
- focusNode → FocusNode?
-
final
- forceErrorText → String?
-
When value is set, text field is in error state; and display this text
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- helperText → String?
-
The optional helper text below the text field
final
- hideKeyboardOnAutofocus → bool
-
final
-
inputFormatters
→ List<
TextInputFormatter> -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardType → TextInputType?
-
final
- label → String?
-
final
- labelIcon → IconData?
-
final
- labelStyle → TextStyle?
-
final
- maxLength → int?
-
final
- maxLines → int?
-
final
- minLines → int?
-
final
- notTrim → bool
-
final
- obscureText → bool
-
final
- onChanged → StringCallback?
-
final
- onDelete → DeleteCallback?
-
final
- onEditingComplete → StringCallback?
-
if a validator is implemented, onEditingComplete gets only triggered, if validator is true (true = returns null) or shouldCompleteNotValidInput is true
final
- onFieldSubmitted → StringCallback?
-
final
- onTap → TapCallback?
-
final
- placeholder → String?
-
final
- placeholderTextStyle → TextStyle?
-
final
- prefixIcon → Widget?
-
final
- prefixLabelIcon → IconData?
-
final
- prefixLabelIconColor → Color?
-
The color of the prefix label icon
final
- readOnly → bool
-
final
- reserveDefaultTextEditingShortcuts → bool
-
Whether the text field should be automatically wrapped with a DefaultTextEditingShortcuts widget or not.
Thus reserving the current platforms default text editing shortcuts and blocking them from being overridden by custom Shortcuts Widgets
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldCompleteNotValidInput → bool
-
final
- slimDesign → bool
-
final
- smartQuotesType → SmartQuotesType?
-
final
- style → YustInputStyle?
-
final
- suffixIcon → Widget?
-
final
- suffixStyle → TextStyle?
-
final
- textCapitalization → TextCapitalization
-
final
- textInputAction → TextInputAction?
-
final
- textStyle → TextStyle?
-
final
- useFilledInputDecoration → bool
-
Whether the TextField should use the decoration from InputDecoration.filled with InputDecoration.fillColor from the current Theme
final
-
validator
→ FormFieldValidator<
String> ? -
final
- value → String?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< YustTextField> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited